@@ -331,6 +331,25 @@ class TestStream:
     )
 
     def test_stream_validity(self):
+        print(f"\nFlows:\n")
+        TestStream.flow1.display()
+        TestStream.flow2.display()
+        TestStream.flow3.display()
+
+        print(f"\nResampled: \n")
+        TestStream.flow1.resample(
+            frequency=rk.duration.Type.BIWEEK,
+            origin=pd.Timestamp(2020, 2, 9),
+        ).display()
+        TestStream.flow2.resample(
+            frequency=rk.duration.Type.BIWEEK,
+            origin=pd.Timestamp(2020, 2, 9),
+        ).display()
+        TestStream.flow3.resample(
+            frequency=rk.duration.Type.BIWEEK,
+            origin=pd.Timestamp(2020, 2, 9),
+        ).display()
+
         TestStream.stream.display()
         TestStream.stream.sum().display()
 
@@ -344,6 +363,8 @@ class TestStream:
         assert TestStream.stream.start_date == pd.Timestamp(2020, 2, 9)
         assert TestStream.stream.end_date == pd.Timestamp(2022, 12, 31)
 
+        assert TestStream.stream.total() == approx(100 - 50 - 50)
+
         # assert (
         #     TestStream.stream.sum().movements.index.size == 24 + 10
         # )  # Two full years plus March-Dec inclusive
@@ -394,11 +415,13 @@ class TestStream:
 
     def test_stream_stream(self):
         collapse = TestStream.stream.collapse()
-        assert collapse.frame["yearly_flow"].iloc[0] == approx(0.0)
+        collapse.display()
+        assert collapse.frame["yearly_flow"].iloc[0] == approx(100.0)
 
-        datestamp = pd.Timestamp(2023, 1, 15)
+        datestamp = pd.Timestamp(2022, 1, 9)
         sum = TestStream.stream.sum()
-        assert sum.movements[datestamp] == approx(33.333333333333336)
+        sum.display()
+        assert sum.movements[datestamp] == approx(32.3529, rel=1e-4)
 
 
 class TestSpan:
